import { NotFoundError } from '../errors.js'
import { fetchFileWithHeaders } from '../files.js'
import createError from 'http-errors'

export default async function (req, res, next) {
  try {
    if (res.body) return
    const path = req.path === '/' ? '/index.html' : req.path
    const { body, headers, sha256Sum } = await fetchFileWithHeaders({ path, version: res.version })
    res.body = body
    res.headers = headers
    res.locals.sha256Sum = sha256Sum
  } catch (err) {
    // response might be an aggregate error. therefore need to check all errors
    const errors = err.errors || [err]
    const fileNotFound = errors.reduce((memo, error) => memo && error instanceof NotFoundError, true)
    if (fileNotFound) next(createError(404, 'File does not exist.'))
    else next(err)
  } finally {
    next()
  }
}
